@@ -2,12 +2,12 @@
 
 =head1 NAME
 
-Net::Google::Search - simple OOP-ish interface to the Google SOAP API for searching
+Net::Google::Search
 
 =head1 SYNOPSIS
 
  use Net::Google::Search;
- my $search = Net::Google::Search($service,\%args);
+ my $search = Net::Google::Search($service,%args);
 
  $search->query(qw(aaron cope));
  map { print $_->title()."\n"; } @{$search->results()};
@@ -26,7 +26,7 @@ use strict;
 use Carp;
 use Exporter;
 
-$Net::Google::Search::VERSION   = 0.2.2;
+$Net::Google::Search::VERSION   = 0.2;
 @Net::Google::Search::ISA       = qw (Exporter);
 @Net::Google::Search::EXPORT    = qw ();
 @Net::Google::Search::EXPORT_OK = qw ();
@@ -41,7 +41,7 @@ use constant RESTRICT_TOPICS => qw [ unclesam linux mac bsd ];
 
 =head1 Class Methods
 
-=head2 $pkg = Net::Google::Search->new($service,\%args)
+=head2 $pkg = Net::Google::Search->new($service,%args)
 
 Where I<$service> is a valid I<GoogleSearchService> object.
 
@@ -49,51 +49,35 @@ Valid arguments are :
 
 =over
 
-=item *
-
-B<key>
+=item B<key>
 
 String. Google API key. If none is provided then the key passed to the parent I<Net::Google> object will be used.
 
-=item *
-
-B<starts_at>
+=item B<starts_at>
 
 Int. First result number to display. Default is 0.
 
-=item *
-
-B<max_results>
+=item B<max_results>
 
 Int. Number of results to return. Default is 10.
 
-=item *
-
-B<lr>
+=item B<lr>
 
 String or array reference. Language restrictions.
 
-=item *
-
-B<ie>
+=item B<ie>
 
 String or array reference. Input encoding.
 
-=item *
-
-B<oe>
+=item B<oe>
 
 String or array reference. Output encoding.
 
-=item *
-
-B<safe>
+=item B<safe>
 
 Boolean.
 
-=item *
-
-B<filter>
+=item B<filter>
 
 Boolean.
 
@@ -526,11 +510,11 @@ sub AUTOLOAD {
 
 =head1 VERSION
 
-0.2.2
+0.2
 
 =head1 DATE
 
-April 15, 2002
+April 13, 2002
 
 =head1 AUTHOR
 
@@ -540,7 +524,7 @@ Aaron Straup Cope
 
 =over
 
-=item *
+=item
 
 Add hooks to manage boolean searches and speacial query strings.
 
@@ -554,8 +538,6 @@ L<Net::Google>
 
 Copyright (c) 2002, Aaron Straup Cope. All Rights Reserved.
 
-This is free software, you may use it and distribute it under the same terms as Perl itself.
-
 =cut
 
 return 1;
